@@ -1058,8 +1058,10 @@ Mat_VarFree(matvar_t *matvar)
             matvar->internal->hdf5_name = NULL;
         }
 #endif
-        if ( NULL != matvar->internal->fieldnames &&
-             matvar->internal->num_fields > 0 ) {
+        /* Stefan Widgren 2014-01-17: Removed check for num_fields >
+         * 0, missing free when number of fields were equal to
+         * zero. */
+        if ( NULL != matvar->internal->fieldnames ) {
             size_t i;
             for ( i = 0; i < matvar->internal->num_fields; i++ ) {
                 if ( NULL != matvar->internal->fieldnames[i] )
